****************************************
clear
use "data.dta" 
************************************************************
************** 被解释变量：企业专利数量 ********************
gen innovation_1 = DP005 
label var  innovation_1 专利件数
gen innovation_2 = DP006
gen innovation_3 = DP007
gen innovation_4 = DP008
gen innovation_5 = innovation_3 + innovation_4
gen sum_innovation = DP006 + DP007 + DP008
gen share_1 = DP006 / sum_innovation
label var share_1 发明专利占比
***************** 解释变量：企业专利质押贷款数量 ****************
gen patentmo_0 = B13261 + B13262 + B13263
gen patentmo_1 = B13261 
label var patentmo_0 专利质押贷款
label var patentmo_1 发明专利质押贷款
gen patentmo_2 = B13262 + B13263
label var patentmo_2 非发明专利质押贷款
encode city, gen(city_code)
label var city_code 城市代码
*******************************************************************
****************** 控制变量 *******************************
gen main_income = A901
label var main_income 企业主营业务收入（万元）
gen profit = A903
label var profit 企业利润总额（万元）
gen num_labor = B101
label var num_labor 企业员工人数
gen competition = B201
label var competition 企业感知的市场竞争度
gen IPP = B2201
label var IPP 企业感知的知识产权保护力度
gen subsidy = .
replace subsidy=1 if B10101==1
replace subsidy=0 if B10101==2
label var subsidy  政府补贴（1有0无）
gen share_RDlabor = B102/B101
replace share_RDlabor=. if share_RDlabor>=1
label var share_RDlabor  企业研发人员数量占比
gen share_RDfee = B104/100
replace share_RDfee=. if share_RDfee>=1
label var share_RDfee 企业研发经费占主营业务收入的比例
************* 缩尾处理 ***********************
winsor2 innovation_1 share_1  main_income profit num_labor /// 
competition IPP subsidy share_RDlabor share_RDfee ,replace cuts(0.5 99.5) trim
gen log_income = log(main_income + 1) 
label var log_income 企业主营业收入的对数值
gen log_profit = log(profit + 1) 
label var log_profit 企业利润总额的对数值
gen firm_size = log(num_labor+1) 
label var firm_size 企业规模
gen ownership = .
destring A701,replace
replace ownership = 1  if  A701==1  /*国有企业*/
replace ownership = 2  if  A701==3  /*私营企业*/
replace ownership = 3  if  A701==5 | A701==7 |A701==8 | A701==9 | A701==10| A701==13| A701==14 | A701==15 |A701==16 | A701==17  /*外资企业*/
replace ownership = 4  if  A701==2 | A701==4 |A701==6 | A701==11 | A701==12| A701==18 /*其他企业*/
label var  ownership  企业所有制类型
gen ownership2 = . 
replace ownership2 = 1 if ownership ==1
replace ownership2 = 0 if ownership !=1
********************************************************************************
**************************** Table 1: statistics *******************************
tabstat innovation_1 share_1 share_RDfee share_RDlabor patentmo_0 patentmo_1 subsidy  competition IPP firm_size  log_profit log_income if patentmo_0!=. & patentmo_1!=. , stat(n mean min max)
tabstat innovation_1 share_1 share_RDfee share_RDlabor patentmo_0 patentmo_1 subsidy  competition IPP firm_size  log_profit log_income if ownership2 == 1 & patentmo_0!=. & patentmo_1!=., stat(n mean min max)
tabstat innovation_1 share_1 share_RDfee share_RDlabor patentmo_0 patentmo_1 subsidy  competition IPP firm_size  log_profit log_income if ownership2 == 0 & patentmo_0!=. & patentmo_1!=., stat(n mean min max)
********************************************************************************
**************************** Table 2 *******************************************
asdoc reg innovation_1  patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest replace
asdoc reg innovation_1  patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg share_1       patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg share_1       patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
********************************************************************************
**************************** Table 3 *******************************************
asdoc reg share_RDlabor  patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest replace
asdoc reg share_RDlabor  patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg share_RDfee  patentmo_0     subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg share_RDfee  patentmo_1     subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
********************************************************************************
**************************** Table 4 *******************************************
replace  B6301 = 0 if  B6301<=2
replace  B6301 = 1 if  B6301>2
gen cross_1 = patentmo_0 * B6301
gen cross_2 = patentmo_1 * B6301
replace B801 = . if B801 ==5
gen cross_3 = patentmo_0 * B801
gen cross_4 = patentmo_1 * B801
asdoc reg innovation_1  patentmo_0 B6301 cross_1  subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest replace
asdoc reg innovation_1  patentmo_1 B6301 cross_2  subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg innovation_1  patentmo_0 B801  cross_3  subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg innovation_1  patentmo_1 B801  cross_4  subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
************* table 5 - different ownership regression ********************
asdoc reg innovation_1  patentmo_0  subsidy competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1, r nest replace
asdoc reg innovation_1  patentmo_1  subsidy competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1, r nest append
asdoc reg innovation_1  patentmo_0  subsidy competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0, r nest append
asdoc reg innovation_1  patentmo_1  subsidy competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0, r nest append
************* table 6 ******************************************************
asdoc reg share_1    patentmo_0  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1  , r nest replace
asdoc reg share_1    patentmo_1  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1  , r nest append
asdoc reg share_1    patentmo_0  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0  , r nest append
asdoc reg share_1    patentmo_1  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0  , r nest append
************* table 7 ******************************************************
asdoc reg share_RDfee   patentmo_0 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1, r nest replace
asdoc reg share_RDfee   patentmo_1 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1, r nest append
asdoc reg share_RDlabor patentmo_0 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1, r nest append
asdoc reg share_RDlabor patentmo_1 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 1, r nest append
asdoc reg share_RDfee   patentmo_0 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0, r nest append
asdoc reg share_RDfee   patentmo_1 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0, r nest append
asdoc reg share_RDlabor patentmo_0 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0, r nest append
asdoc reg share_RDlabor patentmo_1 subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if ownership2 == 0, r nest append
************* table 8 ******************************************************
 *** 按企业规模划分
egen median_size = median(firm_size)
asdoc reg innovation_1  patentmo_0    subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size>= median_size , r nest replace
asdoc reg innovation_1  patentmo_1    subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size>= median_size  , r nest append
asdoc reg innovation_1  patentmo_0    subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size< median_size  , r nest append
asdoc reg innovation_1  patentmo_1    subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size< median_size  , r nest append
************* table 9 ******************************************************
asdoc reg share_1    patentmo_0  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size>= median_size   , r nest replace
asdoc reg share_1    patentmo_1  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size>= median_size   , r nest append
asdoc reg share_1    patentmo_0  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size< median_size  , r nest append
asdoc reg share_1    patentmo_1  subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code  if firm_size< median_size  , r nest append
************* table 10 ******************************************************
asdoc reg share_RDfee    patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size>= median_size  , r nest replace
asdoc reg share_RDfee    patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size>= median_size  , r nest append
asdoc reg share_RDlabor  patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size>= median_size  , r nest append
asdoc reg share_RDlabor  patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size>= median_size  , r nest append
asdoc reg share_RDfee    patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size< median_size  , r nest append
asdoc reg share_RDfee    patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size< median_size  , r nest append
asdoc reg share_RDlabor  patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size< median_size  , r nest append
asdoc reg share_RDlabor  patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.city_code  i.industry_code    if firm_size< median_size  , r nest append
********************************************************************************
************************** table 11 - iv regression *****************************
bysort province : egen total = total(patentmo_0)
bysort province : gen N = _N
bysort province : gen average = (total - patentmo_0) / (N-1)
ivreg2 innovation_1 subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code (patentmo_0 = average), r first 
ivreg2 share_1      subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code (patentmo_0 = average), r first 
bysort province : egen total1 = total(patentmo_1)
bysort province : gen N1 = _N
bysort province : gen average1 = (total1 - patentmo_1) / (N1-1)
ivreg2 innovation_1 subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code (patentmo_1 = average1), r first 
ivreg2 share_1      subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code (patentmo_1 = average1), r first 
***********************************************************
********************************************************************************
merge 1:1 firmname using "data2.dta" 
keep if _merge==3
drop _merge
gen share_1_2015 = innovation_2_2015 / innovation_1_2015
********************************************************************************
**************************** Table 12****************************************
asdoc reg innovation_1_2015  patentmo_0 subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest replace
asdoc reg innovation_1_2015  patentmo_1 subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg share_1_2015       patentmo_0 subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg share_1_2015       patentmo_1 subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
**************************** Table 13****************************************
gen change_patent = innovation_1_2015 - DP005
gen change_patent1 = innovation_2_2015 - DP006
winsor2 change_patent change_patent1, replace cuts(0.5 99.5) 
asdoc reg change_patent  patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest replace
asdoc reg change_patent  patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg change_patent1  patentmo_0   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append
asdoc reg change_patent1  patentmo_1   subsidy  competition IPP firm_size  log_profit log_income i.ownership2  i.city_code  i.industry_code , r nest append